aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-msdp.c
diff options
context:
space:
mode:
Diffstat (limited to 'epan/dissectors/packet-msdp.c')
-rw-r--r--epan/dissectors/packet-msdp.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/epan/dissectors/packet-msdp.c b/epan/dissectors/packet-msdp.c
index 430d1a5962..1d1e29003f 100644
--- a/epan/dissectors/packet-msdp.c
+++ b/epan/dissectors/packet-msdp.c
@@ -339,10 +339,11 @@ static void dissect_msdp_sa(tvbuff_t *tvb, packet_info *pinfo,
reported_length = length;
next_tvb = tvb_new_subset_length(tvb, *offset, reported_length);
/* Set the information columns read-only so that they
* reflect the MSDP packet rather than the
* encapsulated packet.
*/
+ col_set_writable(pinfo->cinfo, COL_PROTOCOL, FALSE);
col_set_writable(pinfo->cinfo, COL_INFO, FALSE);
call_dissector(ip_handle, next_tvb, pinfo, enc_tree);
}
@@ -339,10 +339,11 @@ static void dissect_msdp_sa(tvbuff_t *tvb, packet_info *pinfo,
reported_length = length;
next_tvb = tvb_new_subset_length(tvb, *offset, reported_length);
- /* Set the information columns read-only so that they
- * reflect the MSDP packet rather than the
+ /* Set the protocol and information columns read-only so
+ * that they reflect the MSDP packet rather than the
* encapsulated packet.
*/